BASE_URL = 'https://pagarme.ze.delivery/1/subscriptions'

CANCEL_SUBSCRIPTION = BASE_URL + '/{0}/cancel'

GET_ALL_SUBSCRIPTIONS = BASE_URL

GET_ALL_SUBSCRIPTIONS_POSTBACKS = BASE_URL + '/{0}/postbacks'

GET_ALL_SUBSCRIPTIONS_TRANSACTIONS = BASE_URL + '/{0}/transactions'

GET_SUBSCRIPTION_BY = BASE_URL

GET_SUBSCRIPTION_POSTBACK_BY_ID = BASE_URL + '/{0}/postbacks/{1}'

REDELIVER_SUBSCRIPTION_POSTBACK_BY_ID = BASE_URL + '/{0}/postbacks/{1}/redeliver'

SETTLE_CHARGES_SUBSCRIPTION = BASE_URL + '/{0}/settle_charge'

UPDATE_SUBSCRIPTION = BASE_URL + '/{0}'
